extern int freedv_current_mode;         // the current FreeDV running mode

#define FREEDV_MODE_1600        0
#define FREEDV_MODE_700         1
#define FREEDV_MODE_700B        2
#define FREEDV_MODE_2400A       3
#define FREEDV_MODE_2400B       4
#define FREEDV_MODE_800XA       5
#define FREEDV_MODE_700C        6
#define FREEDV_MODE_700D        7
#define FREEDV_MODE_2020        8
#define FREEDV_MODE_700E        13
